@@ -121,16 +121,18 @@ if not BUILD_GCLOUD_REST:
         def session(self)                         :
             if not self._session:
                 connector = aiohttp.TCPConnector(ssl=self._ssl)
+                timeout = aiohttp.ClientTimeout(self._timeout)
                 self._session = aiohttp.ClientSession(connector=connector,
-                                                      timeout=self._timeout)
+                                                      timeout=timeout)
             return self._session
 
         def post(self, url     , headers                ,
                        data                = None, timeout      = 10,
                        params                           = None
                        )                          :
+            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.post(url, data=data, headers=headers,
-                                           timeout=timeout, params=params)
+                                           timeout=timeout_, params=params)
             _raise_for_status(resp)
             return resp
 
@@ -142,8 +144,9 @@ if not BUILD_GCLOUD_REST:
                 log.warning('passed unused argument stream=%s to AioSession: '
                             'this argument is only used by SyncSession',
                             stream)
+            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.get(url, headers=headers,
-                                          timeout=timeout, params=params)
+                                          timeout=timeout_, params=params)
             _raise_for_status(resp)
             return resp
 
@@ -151,15 +154,17 @@ if not BUILD_GCLOUD_REST:
                         data                = None, timeout      = 10,
                         params                           = None
                         )                          :
+            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.patch(url, data=data, headers=headers,
-                                            timeout=timeout, params=params)
+                                            timeout=timeout_, params=params)
             _raise_for_status(resp)
             return resp
 
         def put(self, url     , headers                , data         ,
                       timeout      = 10)                          :
+            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.put(url, data=data, headers=headers,
-                                          timeout=timeout)
+                                          timeout=timeout_)
             _raise_for_status(resp)
             return resp
 
@@ -167,8 +172,9 @@ if not BUILD_GCLOUD_REST:
                          params                           = None,
                          timeout      = 10
                          )                          :
+            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.delete(url, headers=headers,
-                                             params=params, timeout=timeout)
+                                             params=params, timeout=timeout_)
             _raise_for_status(resp)
             return resp
 
